@@ -38,9 +38,14 @@ from snaptrade_client.model.brokerage_authorization_refresh_confirmation import
 from snaptrade_client.model.brokerage_authorization_type_read_only import BrokerageAuthorizationTypeReadOnly
 from snaptrade_client.model.brokerage_authorization_type_read_only_brokerage import BrokerageAuthorizationTypeReadOnlyBrokerage
 from snaptrade_client.model.brokerage_exchanges import BrokerageExchanges
+from snaptrade_client.model.brokerage_id import BrokerageID
+from snaptrade_client.model.brokerage_instrument import BrokerageInstrument
+from snaptrade_client.model.brokerage_instruments_response import BrokerageInstrumentsResponse
 from snaptrade_client.model.brokerage_order_id import BrokerageOrderID
 from snaptrade_client.model.brokerage_symbol_id import BrokerageSymbolID
 from snaptrade_client.model.brokerage_type import BrokerageType
+from snaptrade_client.model.cancel_order_response import CancelOrderResponse
+from snaptrade_client.model.cancel_order_response_raw_response import CancelOrderResponseRawResponse
 from snaptrade_client.model.child_brokerage_order_ids import ChildBrokerageOrderIDs
 from snaptrade_client.model.child_brokerage_order_ids_nullable import ChildBrokerageOrderIDsNullable
 from snaptrade_client.model.client_id import ClientID
@@ -81,6 +86,8 @@ from snaptrade_client.model.mleg_instrument_type import MlegInstrumentType
 from snaptrade_client.model.mleg_leg import MlegLeg
 from snaptrade_client.model.mleg_order_response import MlegOrderResponse
 from snaptrade_client.model.mleg_order_type_strict import MlegOrderTypeStrict
+from snaptrade_client.model.mleg_price_effect_strict import MlegPriceEffectStrict
+from snaptrade_client.model.mleg_price_effect_strict_nullable import MlegPriceEffectStrictNullable
 from snaptrade_client.model.mleg_trade_form import MlegTradeForm
 from snaptrade_client.model.mleg_trading_instrument import MlegTradingInstrument
 from snaptrade_client.model.model400_failed_request_response import Model400FailedRequestResponse
