@@ -443,6 +443,13 @@ operation_parameter_map = {
             },
         ]
     },
+    '/brokerages/{brokerageId}/instruments-GET': {
+        'parameters': [
+            {
+                'name': 'brokerageId'
+            },
+        ]
+    },
     '/brokerages-GET': {
         'parameters': [
         ]
@@ -471,7 +478,7 @@ operation_parameter_map = {
             },
         ]
     },
-    '/accounts/{accountId}/trading/simple/{brokerageOrderId}/cancel-POST': {
+    '/accounts/{accountId}/trading/cancel-POST': {
         'parameters': [
             {
                 'name': 'userId'
@@ -483,7 +490,7 @@ operation_parameter_map = {
                 'name': 'accountId'
             },
             {
-                'name': 'brokerageOrderId'
+                'name': 'brokerage_order_id'
             },
         ]
     },
@@ -684,6 +691,9 @@ operation_parameter_map = {
             {
                 'name': 'stop_price'
             },
+            {
+                'name': 'price_effect'
+            },
         ]
     },
     '/trade/{tradeId}-POST': {
