@@ -341,7 +341,7 @@ class BaseApi(api_client.Api):
         AsyncGeneratorResponse,
     ]:
         """
-        Creates an option strategy object that will be used to place an option strategy order
+        Create options strategy
         :param skip_deserialization: If true then api_response.response will be set but
             api_response.body and api_response.headers will not be deserialized into schema
             class instances
@@ -487,7 +487,7 @@ class BaseApi(api_client.Api):
         api_client.ApiResponseWithoutDeserialization,
     ]:
         """
-        Creates an option strategy object that will be used to place an option strategy order
+        Create options strategy
         :param skip_deserialization: If true then api_response.response will be set but
             api_response.body and api_response.headers will not be deserialized into schema
             class instances
@@ -640,6 +640,7 @@ class GetOptionStrategy(BaseApi):
         ApiResponseFor200,
         api_client.ApiResponseWithoutDeserialization,
     ]:
+        """ Creates an option strategy object that will be used to place an option strategy order.  """
         args = self._get_option_strategy_mapped_args(
             body=body,
             query_params=query_params,
@@ -710,6 +711,7 @@ class ApiForpost(BaseApi):
         ApiResponseFor200,
         api_client.ApiResponseWithoutDeserialization,
     ]:
+        """ Creates an option strategy object that will be used to place an option strategy order.  """
         args = self._get_option_strategy_mapped_args(
             body=body,
             query_params=query_params,
