@@ -33,16 +33,16 @@ import frozendict  # noqa: F401
 from snaptrade_client import schemas  # noqa: F401
 
 from snaptrade_client.model.strategy_order_record import StrategyOrderRecord as StrategyOrderRecordSchema
-from snaptrade_client.model.order_type import OrderType as OrderTypeSchema
 from snaptrade_client.model.model500_unexpected_exception_response import Model500UnexpectedExceptionResponse as Model500UnexpectedExceptionResponseSchema
 from snaptrade_client.model.price import Price as PriceSchema
 from snaptrade_client.model.time_in_force_strict import TimeInForceStrict as TimeInForceStrictSchema
+from snaptrade_client.model.order_type_strict import OrderTypeStrict as OrderTypeStrictSchema
 
 from snaptrade_client.type.time_in_force_strict import TimeInForceStrict
 from snaptrade_client.type.strategy_order_record import StrategyOrderRecord
 from snaptrade_client.type.model500_unexpected_exception_response import Model500UnexpectedExceptionResponse
+from snaptrade_client.type.order_type_strict import OrderTypeStrict
 from snaptrade_client.type.price import Price
-from snaptrade_client.type.order_type import OrderType
 
 from . import path
 
@@ -133,8 +133,8 @@ class SchemaForRequestBodyApplicationJson(
         class properties:
         
             @staticmethod
-            def order_type() -> typing.Type['OrderType']:
-                return OrderType
+            def order_type() -> typing.Type['OrderTypeStrict']:
+                return OrderTypeStrict
         
             @staticmethod
             def time_in_force() -> typing.Type['TimeInForceStrict']:
@@ -150,10 +150,10 @@ class SchemaForRequestBodyApplicationJson(
             }
     
     time_in_force: 'TimeInForceStrict'
-    order_type: 'OrderType'
+    order_type: 'OrderTypeStrict'
     
     @typing.overload
-    def __getitem__(self, name: typing_extensions.Literal["order_type"]) -> 'OrderType': ...
+    def __getitem__(self, name: typing_extensions.Literal["order_type"]) -> 'OrderTypeStrict': ...
     
     @typing.overload
     def __getitem__(self, name: typing_extensions.Literal["time_in_force"]) -> 'TimeInForceStrict': ...
@@ -170,7 +170,7 @@ class SchemaForRequestBodyApplicationJson(
     
     
     @typing.overload
-    def get_item_oapg(self, name: typing_extensions.Literal["order_type"]) -> 'OrderType': ...
+    def get_item_oapg(self, name: typing_extensions.Literal["order_type"]) -> 'OrderTypeStrict': ...
     
     @typing.overload
     def get_item_oapg(self, name: typing_extensions.Literal["time_in_force"]) -> 'TimeInForceStrict': ...
@@ -189,7 +189,7 @@ class SchemaForRequestBodyApplicationJson(
         cls,
         *args: typing.Union[dict, frozendict.frozendict, ],
         time_in_force: 'TimeInForceStrict',
-        order_type: 'OrderType',
+        order_type: 'OrderTypeStrict',
         price: typing.Union['Price', schemas.Unset] = schemas.unset,
         _configuration: typing.Optional[schemas.Configuration] = None,
         **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
@@ -273,7 +273,7 @@ class BaseApi(api_client.Api):
     def _place_option_strategy_mapped_args(
         self,
         body: typing.Optional[typing.Any] = None,
-        order_type: typing.Optional[OrderType] = None,
+        order_type: typing.Optional[OrderTypeStrict] = None,
         time_in_force: typing.Optional[TimeInForceStrict] = None,
         user_id: typing.Optional[str] = None,
         user_secret: typing.Optional[str] = None,
@@ -323,7 +323,7 @@ class BaseApi(api_client.Api):
         AsyncGeneratorResponse,
     ]:
         """
-        Place an option strategy order on the brokerage
+        Place an option strategy order
         :param skip_deserialization: If true then api_response.response will be set but
             api_response.body and api_response.headers will not be deserialized into schema
             class instances
@@ -377,6 +377,7 @@ class BaseApi(api_client.Api):
             resource_path=used_path,
             method=method,
             configuration=self.api_client.configuration,
+            path_template='/accounts/{accountId}/optionStrategy/{optionStrategyId}/execute',
             body=body,
             auth_settings=_auth,
             headers=_headers,
@@ -469,7 +470,7 @@ class BaseApi(api_client.Api):
         api_client.ApiResponseWithoutDeserialization,
     ]:
         """
-        Place an option strategy order on the brokerage
+        Place an option strategy order
         :param skip_deserialization: If true then api_response.response will be set but
             api_response.body and api_response.headers will not be deserialized into schema
             class instances
@@ -523,6 +524,7 @@ class BaseApi(api_client.Api):
             resource_path=used_path,
             method=method,
             configuration=self.api_client.configuration,
+            path_template='/accounts/{accountId}/optionStrategy/{optionStrategyId}/execute',
             body=body,
             auth_settings=_auth,
             headers=_headers,
@@ -575,7 +577,7 @@ class PlaceOptionStrategy(BaseApi):
     async def aplace_option_strategy(
         self,
         body: typing.Optional[typing.Any] = None,
-        order_type: typing.Optional[OrderType] = None,
+        order_type: typing.Optional[OrderTypeStrict] = None,
         time_in_force: typing.Optional[TimeInForceStrict] = None,
         user_id: typing.Optional[str] = None,
         user_secret: typing.Optional[str] = None,
@@ -612,7 +614,7 @@ class PlaceOptionStrategy(BaseApi):
     def place_option_strategy(
         self,
         body: typing.Optional[typing.Any] = None,
-        order_type: typing.Optional[OrderType] = None,
+        order_type: typing.Optional[OrderTypeStrict] = None,
         time_in_force: typing.Optional[TimeInForceStrict] = None,
         user_id: typing.Optional[str] = None,
         user_secret: typing.Optional[str] = None,
@@ -625,6 +627,7 @@ class PlaceOptionStrategy(BaseApi):
         ApiResponseFor200,
         api_client.ApiResponseWithoutDeserialization,
     ]:
+        """ Places the option strategy order and returns the order record received from the brokerage. """
         args = self._place_option_strategy_mapped_args(
             body=body,
             query_params=query_params,
@@ -649,7 +652,7 @@ class ApiForpost(BaseApi):
     async def apost(
         self,
         body: typing.Optional[typing.Any] = None,
-        order_type: typing.Optional[OrderType] = None,
+        order_type: typing.Optional[OrderTypeStrict] = None,
         time_in_force: typing.Optional[TimeInForceStrict] = None,
         user_id: typing.Optional[str] = None,
         user_secret: typing.Optional[str] = None,
@@ -686,7 +689,7 @@ class ApiForpost(BaseApi):
     def post(
         self,
         body: typing.Optional[typing.Any] = None,
-        order_type: typing.Optional[OrderType] = None,
+        order_type: typing.Optional[OrderTypeStrict] = None,
         time_in_force: typing.Optional[TimeInForceStrict] = None,
         user_id: typing.Optional[str] = None,
         user_secret: typing.Optional[str] = None,
@@ -699,6 +702,7 @@ class ApiForpost(BaseApi):
         ApiResponseFor200,
         api_client.ApiResponseWithoutDeserialization,
     ]:
+        """ Places the option strategy order and returns the order record received from the brokerage. """
         args = self._place_option_strategy_mapped_args(
             body=body,
             query_params=query_params,
