@@ -33,6 +33,7 @@ import frozendict  # noqa: F401
 from snaptrade_client import schemas  # noqa: F401
 
 from snaptrade_client.model.model400_failed_request_response import Model400FailedRequestResponse as Model400FailedRequestResponseSchema
+from snaptrade_client.model.mleg_price_effect_strict_nullable import MlegPriceEffectStrictNullable as MlegPriceEffectStrictNullableSchema
 from snaptrade_client.model.mleg_leg import MlegLeg as MlegLegSchema
 from snaptrade_client.model.mleg_order_type_strict import MlegOrderTypeStrict as MlegOrderTypeStrictSchema
 from snaptrade_client.model.time_in_force_strict import TimeInForceStrict as TimeInForceStrictSchema
@@ -45,6 +46,7 @@ from snaptrade_client.type.mleg_order_type_strict import MlegOrderTypeStrict
 from snaptrade_client.type.model400_failed_request_response import Model400FailedRequestResponse
 from snaptrade_client.type.time_in_force_strict import TimeInForceStrict
 from snaptrade_client.type.mleg_order_response import MlegOrderResponse
+from snaptrade_client.type.mleg_price_effect_strict_nullable import MlegPriceEffectStrictNullable
 
 from . import path
 
@@ -207,6 +209,7 @@ class BaseApi(api_client.Api):
         account_id: typing.Optional[str] = None,
         limit_price: typing.Optional[typing.Optional[str]] = None,
         stop_price: typing.Optional[typing.Optional[str]] = None,
+        price_effect: typing.Optional[MlegPriceEffectStrictNullable] = None,
         query_params: typing.Optional[dict] = {},
         path_params: typing.Optional[dict] = {},
     ) -> api_client.MappedArgs:
@@ -222,6 +225,8 @@ class BaseApi(api_client.Api):
             _body["limit_price"] = limit_price
         if stop_price is not None:
             _body["stop_price"] = stop_price
+        if price_effect is not None:
+            _body["price_effect"] = price_effect
         if legs is not None:
             _body["legs"] = legs
         args.body = body if body is not None else _body
@@ -252,7 +257,7 @@ class BaseApi(api_client.Api):
         AsyncGeneratorResponse,
     ]:
         """
-        Place multi-leg option order
+        Place option order
         :param skip_deserialization: If true then api_response.response will be set but
             api_response.body and api_response.headers will not be deserialized into schema
             class instances
@@ -398,7 +403,7 @@ class BaseApi(api_client.Api):
         api_client.ApiResponseWithoutDeserialization,
     ]:
         """
-        Place multi-leg option order
+        Place option order
         :param skip_deserialization: If true then api_response.response will be set but
             api_response.body and api_response.headers will not be deserialized into schema
             class instances
@@ -512,6 +517,7 @@ class PlaceMlegOrder(BaseApi):
         account_id: typing.Optional[str] = None,
         limit_price: typing.Optional[typing.Optional[str]] = None,
         stop_price: typing.Optional[typing.Optional[str]] = None,
+        price_effect: typing.Optional[MlegPriceEffectStrictNullable] = None,
         query_params: typing.Optional[dict] = {},
         path_params: typing.Optional[dict] = {},
         **kwargs,
@@ -532,6 +538,7 @@ class PlaceMlegOrder(BaseApi):
             account_id=account_id,
             limit_price=limit_price,
             stop_price=stop_price,
+            price_effect=price_effect,
         )
         return await self._aplace_mleg_order_oapg(
             body=args.body,
@@ -551,6 +558,7 @@ class PlaceMlegOrder(BaseApi):
         account_id: typing.Optional[str] = None,
         limit_price: typing.Optional[typing.Optional[str]] = None,
         stop_price: typing.Optional[typing.Optional[str]] = None,
+        price_effect: typing.Optional[MlegPriceEffectStrictNullable] = None,
         query_params: typing.Optional[dict] = {},
         path_params: typing.Optional[dict] = {},
     ) -> typing.Union[
@@ -570,6 +578,7 @@ class PlaceMlegOrder(BaseApi):
             account_id=account_id,
             limit_price=limit_price,
             stop_price=stop_price,
+            price_effect=price_effect,
         )
         return self._place_mleg_order_oapg(
             body=args.body,
@@ -591,6 +600,7 @@ class ApiForpost(BaseApi):
         account_id: typing.Optional[str] = None,
         limit_price: typing.Optional[typing.Optional[str]] = None,
         stop_price: typing.Optional[typing.Optional[str]] = None,
+        price_effect: typing.Optional[MlegPriceEffectStrictNullable] = None,
         query_params: typing.Optional[dict] = {},
         path_params: typing.Optional[dict] = {},
         **kwargs,
@@ -611,6 +621,7 @@ class ApiForpost(BaseApi):
             account_id=account_id,
             limit_price=limit_price,
             stop_price=stop_price,
+            price_effect=price_effect,
         )
         return await self._aplace_mleg_order_oapg(
             body=args.body,
@@ -630,6 +641,7 @@ class ApiForpost(BaseApi):
         account_id: typing.Optional[str] = None,
         limit_price: typing.Optional[typing.Optional[str]] = None,
         stop_price: typing.Optional[typing.Optional[str]] = None,
+        price_effect: typing.Optional[MlegPriceEffectStrictNullable] = None,
         query_params: typing.Optional[dict] = {},
         path_params: typing.Optional[dict] = {},
     ) -> typing.Union[
@@ -649,6 +661,7 @@ class ApiForpost(BaseApi):
             account_id=account_id,
             limit_price=limit_price,
             stop_price=stop_price,
+            price_effect=price_effect,
         )
         return self._place_mleg_order_oapg(
             body=args.body,
