@@ -13,21 +13,11 @@
 from datetime import datetime, date
 import typing
 from enum import Enum
-from typing_extensions import TypedDict, Literal
+from typing_extensions import TypedDict, Literal, TYPE_CHECKING
 
-from snaptrade_client.type.account import Account
-from snaptrade_client.type.account_meta import AccountMeta
-from snaptrade_client.type.account_sync_status import AccountSyncStatus
-from snaptrade_client.type.action import Action
-from snaptrade_client.type.cash import Cash
-from snaptrade_client.type.cash_restriction import CashRestriction
-from snaptrade_client.type.currency import Currency
 from snaptrade_client.type.manual_trade import ManualTrade
 from snaptrade_client.type.manual_trade_balance import ManualTradeBalance
-from snaptrade_client.type.manual_trade_symbol import ManualTradeSymbol
-from snaptrade_client.type.order_type import OrderType
-from snaptrade_client.type.price import Price
-from snaptrade_client.type.time_in_force import TimeInForce
+from snaptrade_client.type.manual_trade_impact import ManualTradeImpact
 
 class RequiredManualTradeAndImpact(TypedDict):
     pass
@@ -35,7 +25,8 @@ class RequiredManualTradeAndImpact(TypedDict):
 class OptionalManualTradeAndImpact(TypedDict, total=False):
     trade: ManualTrade
 
-    trade_impacts: typing.List[ManualTrade]
+    # List of impacts of the trade on the account. The list always contains one value at the moment.
+    trade_impacts: typing.List[ManualTradeImpact]
 
     combined_remaining_balance: ManualTradeBalance
 
