@@ -13,9 +13,11 @@
 from datetime import datetime, date
 import typing
 from enum import Enum
-from typing_extensions import TypedDict, Literal
+from typing_extensions import TypedDict, Literal, TYPE_CHECKING
 
 from snaptrade_client.type.option_strategy import OptionStrategy
+from snaptrade_client.type.price import Price
+from snaptrade_client.type.strategy_quotes_greek import StrategyQuotesGreek
 
 class RequiredStrategyQuotes(TypedDict):
     pass
@@ -23,18 +25,15 @@ class RequiredStrategyQuotes(TypedDict):
 class OptionalStrategyQuotes(TypedDict, total=False):
     strategy: OptionStrategy
 
-    # Trade Price if limit or stop limit order
-    open_price: typing.Union[int, float]
+    open_price: Price
 
-    # Trade Price if limit or stop limit order
-    bid_price: typing.Union[int, float]
+    bid_price: Price
 
-    # Trade Price if limit or stop limit order
-    ask_price: typing.Union[int, float]
+    ask_price: Price
 
     volatility: typing.Union[int, float]
 
-    greek: typing.Dict[str, typing.Union[bool, date, datetime, dict, float, int, list, str, None]]
+    greek: StrategyQuotesGreek
 
 class StrategyQuotes(RequiredStrategyQuotes, OptionalStrategyQuotes):
     pass
